
input[type="checkbox"] {
 -moz-border-radius:0px; 
 width:12px; 
 height:12px; 
 border:1px solid black; 
 background-color:rgb(200, 200, 200);
}

input[type="radio"] {
 width:14px; 
 height:14px; 
 border:1px solid black; 
 background-color:rgb(200, 200, 200);
}

input[type=button] {
 padding-left:10px; 
 padding-right:10px; 
 border:1px solid black;
 -moz-border-radius:5px;
 font-weight:bold;
}

select {
  -moz-border-radius:5px;
  border:1px solid black;
  background-color:rgb(200, 200, 200);
}

:-moz-dropdown-list {
  border-color:black;
  background-color:rgb(200, 200, 200);
}

option {
 padding-left:10px;
}

option:checked {
  color:black;
  background-color:rgb(255, 221, 255);
  padding-left:10px;
}
  
